/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */


#ifndef SRC_CONSTRAINT_ANALYSIS_ENERGY_BASED_H_
#define SRC_CONSTRAINT_ANALYSIS_ENERGY_BASED_H_

 /* === Includes === */
#include <filesystem>
#include <memory>
#include <optional>
#include <unordered_map>
#include <unordered_set>
#include <string>
#include <string_view>
#include "../ca_strategy.h"
#include <engine/engine.h>
#include "../../include/constraint_analysis/ca_functions.h"
#include "../../include/constraint_analysis/ca_parser.h"
#include "../constraint_analysis.h"
#include "../../include/constraint_analysis/ca_plotting.h"
#include "../io/aircraft_xml.h"
#include "../../include/constraint_analysis/ca_minfinder.h"


class EnergyBased : public ConstraintAnalysisStrategy
{
public:
    /* === Constructors === */
    /**
     * @brief Construct a new energy based constraint analysis.
     * @param configuration The module configuration provided by the user.
     */
    explicit EnergyBased(
        const std::shared_ptr<node>& configuration, 
        const std::shared_ptr<node>& polar,
        const std::shared_ptr<node>& aircraft_xml,
        const std::filesystem::path& engine_directory,
        const std::filesystem::path& mission_directory, 
        const std::filesystem::path& plot_dir
        ) : ConstraintAnalysisStrategy(configuration, polar, aircraft_xml, engine_directory, mission_directory, plot_dir) {}

    /* === Methods === */
    /**
     * @brief Finalize the initialization of the constraint analysis.
     */
    void initialize();

    void operator()(); // NOLINT runtime/references

    void assess_constraints(std::vector<double>& W_over_S_data, Mattingly::constraint_analysis& constraint_analysis_tool, readMission& mission_data, Engine& engine);

    std::vector<Constraint> constraint_list = {};
    std::vector<double> lower_boundaries = {};
    std::vector<double> upper_boundaries = {};
}; // namespace design

#endif // SRC_CONSTRAINT_ANALYSIS_ENERGY_BASED_H_