/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include <string>
#include <vector>
#include <memory>
#include <filesystem>
#include <iostream>
#include <map>

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>
#include <aixml/node.h>
#include <runtimeInfo/runtimeInfo.h>
#include "ecological_assessment.h"
#include "standard_strategy/standard_strategy.h"

namespace fs = std::filesystem;

/**
 * @brief Construct a new EcologicalAssessment:: EcologicalAssessment object
 *
 * @param toolName entry from toolinfo.h
 * @param toolVersion entry from toolinfo.h
 */
EcologicalAssessment::EcologicalAssessment(const int argc, char *argv[], const std::string &toolName, const std::string &toolVersion)
    : Module(argc, argv, toolName, toolVersion) {
  rtIO_ = get_RuntimeIO();

  /* Set strategy route (by now, only one standard strategy exists which offers the possibility to use different methods) */
  std::string strategy_name(rtIO_->moduleConfig.at("program_settings/strategy_selector/value"));
  strategy_.registerStrategy<StandardStrategy>({"STANDARD"});
  strategy_.setStrategy({strategy_name}, rtIO_);
}

