# UNICADO - UNIversity Conceptual Aircraft Design and Optimization
#
# Copyright (C) 2025 UNICADO consortium
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# Description:
# This file is part of UNICADO.

def payload_tube_floor_thickness_calculation(payload_tube_wall_thickness, runtime_output):
    """ Calculates payload tube floor thicknesses from given payload tube wall thickness.
        References and calculation method:
            [1] Prof. Dr.-Ing. Juergen Thorbeck TU-Berlin (2006), Script "Flugzeugentwurf I und II" page: XYZ
                cabin_floor_thickness = 1.5 * wall_thickness [inch]

    :param dict payload_tube_wall_thickness: Dict containing all payload tube wall thicknesses from current project
    :param logging.Logger runtime_output: Logging object used for capturing log messages in the module
    :return dict payload_tube_floor_thickness: Dict containing all payload tube floor thicknesses.
    """
    ''' initialize local parameter '''
    payload_tube_floor_thickness = {}

    # Calculation of floor thickness according to [1].
    for payload_tube, cabin_wall_thickness in payload_tube_wall_thickness.items():
        payload_tube_floor_thickness[payload_tube] = round(1.5 * cabin_wall_thickness, 3)

    ''' debug print '''
    runtime_output.debug('Debug: The payload_tube_floor_thickness_calculation function was successfully executed!')

    return payload_tube_floor_thickness
