/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "TawInitialSizingConfig.h"
#include <algorithm>
#include <aixml/node.h>
#include <standardFiles/functions.h>
#include <string>

/* Methods for reading program settings of config */

void TawInitialSizingConfig::readProgramSettings(const node& config) {
        designCase = config.at("/module_configuration_file/program_settings/design_case/value");
    if (designCase == true) {
        theProgramName = std::string(TOOL_NAME) + "_design";
    } else {
        theProgramName = std::string(TOOL_NAME) + "_study";
    }
    /* read Mass fraction for different mission segments and SFC constants */
    ff_warmup = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/Masses/Fractions/mf_warmup/value");
    ff_taxi = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/Masses/Fractions/mf_taxi/value");
    ff_takeoff = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/Masses/Fractions/mf_to/value");
    ff_climb = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/Masses/Fractions/mf_climb/value");
    ff_descent = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/Masses/Fractions/mf_descent/value");
    ff_land = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/Masses/Fractions/mf_land/value");
    ff_missedandclimb = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/Masses/Fractions/mf_missedandclimb/value");
    SFCKerosene = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/Constants/SFC_kerosene/value");
    /* read lift to drag ratio at initial cruise and loiter */
    LDInitialCruise = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/LiftToDragRatios/LD_initial_cruise/value");
    LDInitialLoiter = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/LiftToDragRatios/LD_initial_loiter/value");
    /* read Number of Pilots and engines */
    numberOfPilots = config.at("/module_configuration_file/program_settings/General/n_pilots/value");
    numberOfEngines = config.at("/module_configuration_file/program_settings/General/n_engines/value");
    Cfeq = config.at("/module_configuration_file/program_settings/General/Cf/value");
    CLmaxTO = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/TOFL/CLmax_TO/value");
    DeltaCD_HL = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/Climb/deltaCD_HL/value");
    AR = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/General/AspectRatio/value");
    e = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/General/OswaldFactor/value");
    CLmaxL = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/LDN/CLmax_L/value");
    ml_mo = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/LDN/mlmo/value");
    mcr_mo = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/Cruise/mcr_mto/value");
    optimalCL = config.at("/module_configuration_file/program_settings/tube_and_wing/analytical_approach/Cruise/optimalCL/value");
    /* Read data for readonly mode */
    wing_loading_user = EndnodeReadOnly<double>("/module_configuration_file/program_settings/tube_and_wing/readonly_approach/wing_loading").read(config).value();
    thrust_loading_user = EndnodeReadOnly<double>("/module_configuration_file/program_settings/tube_and_wing/readonly_approach/thrust_loading").read(config).value();
    maximum_takeoff_mass_user = EndnodeReadOnly<double>(
        "/module_configuration_file/program_settings/tube_and_wing/readonly_approach/maximum_takeoff_mass_start").read(config).value();
    operating_mass_empty_user = EndnodeReadOnly<double>(
        "/module_configuration_file/program_settings/tube_and_wing/readonly_approach/operating_mass_empty_start").read(config).value();
}
