/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "TawAnalytical.h"
#include "../../toolinfo.h"
#include <vector>
#include <matplot/matplot.h>
#include <string>
#include <iostream>


void TawAnalytical::generatePlotData() {
    // Create figure
    auto fig = matplot::gcf();
    fig->quiet_mode(true);
    auto ax = fig->current_axes();

    ax->hold(true);
    
    auto takeoffPlot = ax->plot(takeoffDataWS, takeoffDataTW, "-r"); 
    takeoffPlot->line_width(2.0);

    auto climbPlot = ax->plot(climbDataWS, climbDataTW, "-k"); 
    climbPlot->line_width(2.0);

    auto cruisePlot = ax->plot(cruiseDataWS, cruiseDataTW, "-g"); 
    cruisePlot->line_width(2.0);

    auto landingPlot = ax->plot(landingDataWS, landingDataTW, "-b"); 
    landingPlot->line_width(2.0);

    auto optiCLPlot = ax->plot(optiCLDataWS, optiCLDataTW, "-m"); 
    optiCLPlot->line_width(2.0);

    std::vector<double> designWS_vec = {designWS_};
    std::vector<double> designTW_vec = {designTW_};
    auto designPlot = ax->plot(designWS_vec, designTW_vec, "ok");
    designPlot->marker_size(6.0); 
    designPlot->marker_face_color("k"); 

    ax->title("Sizing Chart");
    ax->xlabel("Wing Loading (W/S)");
    ax->ylabel("Thrust-to-Weight Ratio (T/W)");

    std::vector<std::string> legendLabels = {"Takeoff", "Climb", "Cruise", "Landing", "Optimum CL", "Design Point"};
    ax->legend(legendLabels);

    ax->x_axis().label_font_size(12);
    ax->y_axis().label_font_size(12);

    std::string plotFilePath = rtIO_->getPlotFilesDir() + "/WS_TW_Plot.svg";
    matplot::save(plotFilePath);

    std::cout << "Plot saved to: " << plotFilePath << std::endl;
}

