# UNICADO - UNIversity Conceptual Aircraft Design and Optimization
#
# Copyright (C) 2025 UNICADO consortium
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# Description:
# This file is part of UNICADO.

import math


def cvrg(dict_acn_flex_parameter, runtime_output):
    # SUBROUTINE CVRG CONVERGES ON REFERENCE THICKNESS

    # initialize local parameter
    x_222 = dict_acn_flex_parameter['X222']
    x_333 = dict_acn_flex_parameter['X333']
    y_111 = dict_acn_flex_parameter['Z'][dict_acn_flex_parameter['KZ']-1]
    y_222 = dict_acn_flex_parameter['Y222']
    y_333 = dict_acn_flex_parameter['Y333']

    # check if the global iteration counter is equal to zero -> if true: -> start first estimation
    if not dict_acn_flex_parameter['ITCT'] == 0:
        dict_acn_flex_parameter['ITCT'] = dict_acn_flex_parameter['ITCT'] + 1

        # check if the maximum number of allowed iteration (100) or convergence is reached
        #  -> if true: -> reset global iteration counter to zero and return with 'False'
        #   -> icao code line 146, 149 and 150 (GoTo CVRG40)
        if dict_acn_flex_parameter['ITCT'] > 100 \
                or abs((dict_acn_flex_parameter['FCTN'] - dict_acn_flex_parameter['TRGT']) /
                       abs(dict_acn_flex_parameter['TRGT'])) < 0.001 \
                or abs((y_222 - y_111) / y_111) < 0.001:

            dict_acn_flex_parameter['ITCT'] = 0
            dict_acn_flex_parameter['ITER'] = False

            # return to acn flex estimation
            return dict_acn_flex_parameter

        # else condition: maximum number of iteration and convergence are not reached
        else:
            # check if the current value of 'FCTN' is not lower than the current value of 'TRGT'
            #  -> if true: -> set y_222 and x_222 case specific values
            if not dict_acn_flex_parameter['FCTN'] < dict_acn_flex_parameter['TRGT']:
                y_222 = y_111
                x_222 = dict_acn_flex_parameter['FCTN']

            # else condition: the current value of 'FCTN' is not equal or grater than the current value of 'TRGT'
            #  -> set y_333 and x_333 case specific values
            else:
                y_333 = y_111
                x_333 = dict_acn_flex_parameter['FCTN']

    # else condition: current execution is not the first one -> icao code line 144 (GoTo CVRG30)
    else:
        dict_acn_flex_parameter['ITCT'] = 1
        y_222 = 0
        x_222 = 300
        y_333 = y_111
        x_333 = dict_acn_flex_parameter['FCTN']

    # final estimation of 'Z' for next loop and return to acn flex estimation -> icao code line 158 (CVRG20)
    y_111 = y_222 + (y_333 - y_222) * (dict_acn_flex_parameter['TRGT'] - x_222) / (x_333 - x_222)
    y_111 = y_222 + (y_333 - y_222) * (math.log10(dict_acn_flex_parameter['TRGT']) - math.log10(x_222)) / \
        (math.log10(x_333) - math.log10(x_222))

    dict_acn_flex_parameter['Z'][dict_acn_flex_parameter['KZ'] - 1] = y_111
    dict_acn_flex_parameter['ITER'] = True
    dict_acn_flex_parameter['X222'] = x_222
    dict_acn_flex_parameter['X333'] = x_333
    dict_acn_flex_parameter['Y111'] = y_111
    dict_acn_flex_parameter['Y222'] = y_222
    dict_acn_flex_parameter['Y333'] = y_333

    runtime_output.debug('cvrg successfully executed!')

    return dict_acn_flex_parameter
