/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 * 
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */
#ifndef PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_FLIGHTENVELOPES_ABSTRACTFLIGHTENVELOPES_H_
#define PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_FLIGHTENVELOPES_ABSTRACTFLIGHTENVELOPES_H_

#include <vector>
#include <memory>

#include "../ceilingPerformance/abstractCeilingPerformance.h"
#include "../aircraft.h"

class abstractFlightEnvelopes {
 public:
    virtual ~abstractFlightEnvelopes() { }
    virtual void doFlightEnvelope(std::shared_ptr<abstractCeilingPerformance> ceilingPerf) = 0;
    virtual void doDiveSpeedLimits() = 0;

    std::shared_ptr<aircraft> theAcftPt;

    /**\class speedLimit Class contains the speed limits for different heights
    *
    */
    class speedLimit {
     public:
        double speed; /**< Aircraft speed (m/s) */
        double height; /**< Aircraft height (m) */

        speedLimit() {
            speed = 0.;
            height = 0.;
        }
    };

    /**\class flightEnvelopeData Class contains aircraft speed and altitude for different gross masses
    *
    */
    class flightEnvelopeData {
     public:
        double grossMass; /**< Aircraft gross mass (kg) */
        std::vector<speedLimit> vStall; /**< List of stall speeds for different altitudes (m/s) */
        std::vector<speedLimit> vMO; /**< List of maximum operating speeds for different altitudes, corrected by the air density (m/s) */
        std::vector<speedLimit> vDive; /**< List of dive speeds for different altitudes, corrected by the air density (m/s) */
        std::vector<speedLimit> MMO; /**< List of maximum operating speeds for different altitudes (m/s) */
        std::vector<speedLimit> MDive; /**< List of dive speeds for different altitudes (m/s) */
        double maxAlt; /**< Maximum flight altitude (m) */

        /**\brief constructor of the flightEnvelopeData object
        *
        */
        flightEnvelopeData() {
            grossMass = 0.0;
            maxAlt = 0.0;
        }
    };
    std::vector<flightEnvelopeData> myFlightEnvelope; /**< List of flight envelope data */

    explicit abstractFlightEnvelopes(std::shared_ptr<aircraft> myAcftPt) : theAcftPt(myAcftPt) { }
};

#endif  // PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_FLIGHTENVELOPES_ABSTRACTFLIGHTENVELOPES_H_
