/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "theGearboxes.h"

#include <runtimeInfo/runtimeInfo.h>

theGearboxes::theGearboxes(const std::string& Type)
    :
    Mass(0.0) {
    if (Type == "Slat") {
        efficiencyFactor = 1.0;
    } else if (Type == "Fowler") {
        efficiencyFactor = 1.0;
    } else {
        myRuntimeInfo->err << "The system type \"" << Type << "\" is unknown. No gearbox can be created!" << std::endl;
        myRuntimeInfo->err << "Abort!" << std::endl;
        exit(1);
    }
    //ctor
}

theGearboxes::~theGearboxes() {
    //dtor
}

void theGearboxes::getMass(const std::string& deviceType, double theMTOM, double wingSref) {
// NOTE (aigner#1#): Urspruenglich s. SA Chavez 2010 S.67, Komplett neue Methode geaendert von Lammering in rev2131 im Maerz 2013
    if (deviceType == "Slat" || deviceType == "Fowler") {
        Mass = 0.5416 * (theMTOM * wingSref * 0.0000001) + 10.322;
    } else {
        myRuntimeInfo->err << "The system type \"" << deviceType << "\" is unknown. Gearbox mass cannot be calculated!" << std::endl;
        myRuntimeInfo->err << "Abort!" << std::endl;
        exit(1);
    }
}
