/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include <string>
#include <vector>
#include <memory>
#include <filesystem>
#include <map>


#include <moduleBasics/strategySelector.h>
#include "systemsDesign.h"

namespace fs = std::filesystem;

systemsDesign::systemsDesign(const int argc, char *argv[], const std::string& toolName, const std::string& toolVersion) : Module(argc, argv, toolName, toolVersion) {
    rtIO_ = get_RuntimeIO();
    std::string method = rtIO_->moduleConfig.at("program_settings/modes/value");
    route_ = {method};
    /* Register existing strategies */
    strategy_.registerStrategy<standardSystemsDesign>({"standard"});
    strategy_.registerStrategy<virtual_systems_design>({"virtual"});
    /* Set desired strategy */
    strategy_.setStrategy(route_, rtIO_);
}
