# UNICADO - UNIversity Conceptual Aircraft Design and Optimization
#
# Copyright (C) 2025 UNICADO consortium
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# Description:
# This file is part of UNICADO.

def calculate_center_of_gravity(runtime_output, tank_shape, diameter_front, diameter_rear, length):
    """Calculate center of gravity.
    
    The coordinates refer to the local reference point. This is located in the lower left corner of the front tank
    section. Only the conical or cylindrical parts of the tank are taken into account. The end caps are not considered.

    :param logging.Logger runtime_output: Logging object used for capturing log messages in the module
    :param str tank_shape: _description_
    :param float diameter_front: Diameter at front end of tank
    :param float diameter_rear: Diameter at rear end of tank
    :param float length: Length of cylindrical/conical tank section
    """

    match tank_shape:
        case 'conical':
            x_coordinate_center_of_gravity = length/3 * (diameter_front + 2*diameter_rear)/(diameter_front
                                                                                            + diameter_rear)
            z_coordinate_center_of_gravity = (diameter_front**2 - diameter_rear**2
                                              + abs(diameter_rear)*(diameter_front + 2*diameter_rear))/(
                                                  3*(diameter_front + diameter_rear))
            runtime_output.debug('Debug: Calculating center of gravity for conical tank.')

        case 'cylindrical':
            x_coordinate_center_of_gravity = length/2
            z_coordinate_center_of_gravity = diameter_front/2
            runtime_output.debug('Debug: Calculating center of gravity for cylindrical tank.')

    y_coordinate_center_of_gravity = 0.0

    # Debug print.
    runtime_output.debug('Debug: The "calculate_center_of_gravity" function was successfully executed.')

    return {'x': float(x_coordinate_center_of_gravity),
            'y': float(y_coordinate_center_of_gravity),
            'z': float(z_coordinate_center_of_gravity)}
